#!/bin/sh
# Start/stop the Kannel boxes: One bearer box and one WAP box.

# This is the default init.d script for Kannel.  Its configuration is
# appropriate for a small site running Kannel on one machine.

# Make sure that the Kannel binaries can be found in $BOXPATH or somewhere
# else along $PATH.  run_kannel_box has to be in $BOXPATH.
# chkconfig: 345 97 03
# description: Kannel WAP/SMS Gateway Init Script
# probe: true

BOXPATH=/usr/local/sbin
PIDFILES=/var/run/kannel
CONF=/etc/kannel/kannel.conf
QCONF=/etc/kannel/sqlbox.conf

USER=kannel

BEARERBOX=/usr/sbin/bearerbox
SMSBOX=/usr/sbin/smsbox

# *** NOTE: wapbox and sqlbox are disabled by default

# *** Uncomment the next line to enable wapbox ***
#WAPBOX=/usr/sbin/wapbox

# *** Uncomment the next line to enable sqlbox ***
#SQLBOX=/usr/sbin/sqlbox

test -x $BEARERBOX || exit 0

case "$1" in
  start)
    echo -n "Starting SMS gateway: "
    
    #bearerbox
    echo -n "bearerbox "
    $BEARERBOX --daemonize --parachute --user $USER $CONF

    #smsbox
    sleep 1
    echo -n "smsbox "
    $SMSBOX --daemonize --parachute --user $USER $CONF

    #wapbox
    if [ "$WAPBOX" != "" ]; then
	sleep 1
	echo -n "wapbox "
	$WAPBOX --daemonize --parachute --user $USER $QCONF
    fi

    #sqlbox
    if [ "$SQLBOX" != "" ]; then
	sleep 1
	echo -n "sqlbox "
	$SQLBOX --daemonize --parachute --user $USER $QCONF
    fi

    echo "."
    ;;

  stop)
    echo -n "Stopping SMS gateway: "
    if [ "$SQLBOX" != "" ]; then
	echo -n "sqlbox "
	killall -INT sqlbox
    fi
    if [ "$WAPBOX" != "" ]; then
	echo -n "wapbox "
	killall -INT wapbox
    fi
    echo -n "smsbox "
    killall -INT smsbox
    echo -n "bearerbox "
    killall -INT bearerbox
    echo "."
    ;;

  reload)
    # We don't have support for this yet.
    exit 1
    ;;

  restart|force-reload)
    $0 stop
    sleep 5
    $0 start
    ;;

  *)
    echo "Usage: $0 {start|stop|reload|restart|force-reload}"
    exit 1

esac

exit 0
